.. _bfg_wiki_tutorial:

ZODB + Traversal Wiki Tutorial
==============================

This tutorial introduces a :term:`ZODB` and :term:`traversal`-based
:app:`Pyramid` application to a developer familiar with Python.  It will be
most familiar to developers with previous :term:`Zope` experience.  When
finished, the developer will have created a basic Wiki application with
authentication.

For cut and paste purposes, the source code for all stages of this
tutorial can be browsed on GitHub at `GitHub <https://github.com/Pylons/pyramid/>`_ for a specific branch or version under ``docs/tutorials/wiki/src``,
which corresponds to the same location if you have Pyramid sources.

.. toctree::
   :maxdepth: 2

   background
   design
   installation
   basiclayout
   definingmodels
   definingviews
   authorization
   tests
   distributing
